---
title: Vocalizr
emoji: 🔊
colorFrom: purple
colorTo: yellow
sdk: docker
app_port: 7860
---

## Vocalizr: Voice Generator part of the Chatacter Backend

[![Code Quality](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/code_quality.yaml/badge.svg)](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/code_quality.yaml)
[![CodeQL](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/github-code-scanning/codeql/badge.svg)](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/github-code-scanning/codeql)
[![Dependabot Updates](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/dependabot/dependabot-updates/badge.svg)](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/dependabot/dependabot-updates)
[![Docker Images](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/docker.yaml/badge.svg)](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/docker.yaml)
[![GitHub Release](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/github.yaml/badge.svg)](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/github.yaml)
[![Push to HuggingFace](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/huggingface.yaml/badge.svg)](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/huggingface.yaml)
[![Upgrade Trunk Check](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/trunk_upgrade.yaml/badge.svg)](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/trunk_upgrade.yaml)
[![Upload Python Package](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/pypi.yaml/badge.svg)](https://github.com/AlphaSphereDotAI/vocalizr/actions/workflows/pypi.yaml)
